# decentriq-platform-client

Python client library for the Decentriq platform.

## Installation

After cloning the repository you can install the library using pip:

### Virtual environment(optional)

Before installing the library you may want to working inside a virtual environment:

```
python -m venv env
source env/bin/activate
```

### Pip

To install with pip just run:

```
pip install .
```

## Usage:

To have an idea of how to use this library, you can check the demo in the `example`
 directory.

## Testing

To start the testing process install `nox` with `pip install nox` and the run it
in the project directory. *N.B. make sure you have an available avato-backend*

**nox**
```
nox
```
